<?php
/*
 *
 * Copyright 2012 Human Resource Information System
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * Reused from FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * @since 2012
 * @author John Francis Mukulu <john.f.mukulu@gmail.com>
 *
 */

namespace Hris\UserBundle\Controller;

use Doctrine\Common\Collections\ArrayCollection;
use FOS\MessageBundle\FormModel\NewThreadMultipleMessage;
use Symfony\Component\DependencyInjection\ContainerAware;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\Security\Core\Exception\AccountStatusException;
use FOS\UserBundle\Model\UserInterface;
use Symfony\Component\Form\Form;
use JMS\SecurityExtraBundle\Annotation\Secure;

/**
 * Controller managing the registration
 *
 * @author Thibault Duplessis <thibault.duplessis@gmail.com>
 * @author Christophe Coevoet <stof@notk.org>
 * @author John Francis Mukulu <john.f.mukulu@gmail.com>
 */
class RegistrationController extends ContainerAware
{
    /**
     * Registers user
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_REGISTER,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     * @return RedirectResponse
     */
    public function registerAction()
    {
        $form = $this->container->get('fos_user.registration.form');
        $formHandler = $this->container->get('fos_user.registration.form.handler');
        $confirmationEnabled = $this->container->getParameter('fos_user.registration.confirmation.enabled');

        $process = $formHandler->process($confirmationEnabled);
        if ($process) {
            $user = $form->getData();

            $authUser = false;
            if ($confirmationEnabled) {
                $this->container->get('session')->set('fos_user_send_confirmation_email/email', $user->getEmail());
                $route = 'fos_user_registration_check_email';
                //@hack authenticate user to avoid redirect bug
                $authUser = true;
            } else {
                $authUser = true;
                $route = 'fos_user_registration_confirmed';
            }

            $this->setFlash('fos_user_success', 'registration.flash.user_created');
            $url = $this->container->get('router')->generate($route);
            $response = new RedirectResponse($url);

            if ($authUser) {
                $this->authenticateUser($user, $response);
            }

            $entityManager = $this->container->get('doctrine.orm.entity_manager');

            $userEntity = $entityManager->getRepository('HrisUserBundle:User')->findOneBy(array('username'=>$form->getData()->getUsername()));

            $messageBody="Hellow! \nThis is an automated self registration notification for ". $userEntity->getFirstname(). " ". $userEntity->getSurname()
                        ." registered with username:".$userEntity->getUsername()." working as ".$userEntity->getJobTitle()
                        ."\n\nKindly activate him/her for duty post ".$userEntity->getDescription()
                        ." and notify him/her via phone number:".$userEntity->getPhonenumber()
                        ." and email:".$userEntity->getEmail()
                        ." after you have assigned him/her with role and duty post.";
            $messageSubject='USER SELF REGISTRATION';
            $formHandler = $this->container->get('fos_message.new_thread_form.handler');
            $sender = $this->container->get('fos_message.sender');

            $newThreadMessage = new NewThreadMultipleMessage();
            $newThreadMessage->setSubject($messageSubject);
            $newThreadMessage->setBody($messageBody);
            //Getting the Users Groups
            $users = $entityManager->getRepository('HrisUserBundle:User')->getUsersFromGroup("Feedback Group");
            //Populate recipients from Feedback user group
            $userCollection = new ArrayCollection();
            foreach($users as $user){
                $userCollection->add($user);
                $newThreadMessage->addRecipient($user);
            }
            $sender->send($formHandler->composeMessage($newThreadMessage));;
            return $response;
        }

        return $this->container->get('templating')->renderResponse('HrisUserBundle:Registration:register.html.'.$this->getEngine(), array(
            'form' => $form->createView(),
        ));
    }

    /**
     * Tell the user to check his email provider
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_CHECKEMAIL,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     */
    public function checkEmailAction()
    {
        $email = $this->container->get('session')->get('fos_user_send_confirmation_email/email');
        $this->container->get('session')->remove('fos_user_send_confirmation_email/email');
        $user = $this->container->get('fos_user.user_manager')->findUserByEmail($email);

        if (null === $user) {
            throw new NotFoundHttpException(sprintf('The user with email "%s" does not exist', $email));
        }

        return $this->container->get('templating')->renderResponse('HrisUserBundle:Registration:checkEmail.html.'.$this->getEngine(), array(
            'user' => $user,
        ));
    }

    /**
     * Receive the confirmation token from user email provider, login the user
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_CONFIRM,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     */
    public function confirmAction($token)
    {
        $user = $this->container->get('fos_user.user_manager')->findUserByConfirmationToken($token);

        if (null === $user) {
            throw new NotFoundHttpException(sprintf('The user with confirmation token "%s" does not exist', $token));
        }

        $user->setConfirmationToken(null);
        $user->setEnabled(true);
        $user->setLastLogin(new \DateTime());

        $this->container->get('fos_user.user_manager')->updateUser($user);
        $response = new RedirectResponse($this->container->get('router')->generate('fos_user_registration_confirmed'));
        $this->authenticateUser($user, $response);

        return $response;
    }

    /**
     * Tell the user his account is now confirmed
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_CONFIRMED,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     */
    public function confirmedAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof UserInterface) {
            throw new AccessDeniedException('This user does not have access to this section.');
        }

        return $this->container->get('templating')->renderResponse('HrisUserBundle:Registration:confirmed.html.'.$this->getEngine(), array(
            'user' => $user,
        ));
    }

    /**
     * Authenticate a user with Symfony Security
     *
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_CONFIRM,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     * @param \FOS\UserBundle\Model\UserInterface        $user
     * @param \Symfony\Component\HttpFoundation\Response $response
     */
    protected function authenticateUser(UserInterface $user, Response $response)
    {
        try {
            $this->container->get('fos_user.security.login_manager')->loginUser(
                $this->container->getParameter('fos_user.firewall_name'),
                $user,
                $response);
        } catch (AccountStatusException $ex) {
            // We simply do not authenticate users which do not pass the user
            // checker (not enabled, expired, etc.).
        }
    }

    /**
     * @Secure(roles="ROLE_SUPER_USER,ROLE_USERREGISTRATION_CONFIRM,IS_AUTHENTICATED_ANONYMOUSLY,ROLE_USER")
     * @param string $action
     * @param string $value
     */
    protected function setFlash($action, $value)
    {
        $this->container->get('session')->getFlashBag()->set($action, $value);
    }

    protected function getEngine()
    {
        return $this->container->getParameter('fos_user.template.engine');
    }
}
